@@ -16,7 +16,7 @@
 #'   (`docname`) and the token index positions (`from` and `to`,
 #'   which will be the same for single-word patterns, or a sequence equal in
 #'   length to the number of elements for multi-word phrases).
-#'   
+#'
 #' @note `pattern` will be a keyword pattern or phrase, possibly multiple
 #'   patterns, that may include punctuation.  If a pattern contains whitespace,
 #'   it is best to wrap it in [phrase()] to make this explicit. However if
@@ -27,6 +27,7 @@
 #' @export
 #' @seealso [print-methods]
 #' @examples
+#' \donttest{
 #' # single token matching
 #' toks <- tokens(data_corpus_inaugural[1:8])
 #' kwic(toks, pattern = "secure*", valuetype = "glob", window = 3)
@@ -36,15 +37,16 @@
 #' # phrase matching
 #' kwic(toks, pattern = phrase("secur* against"), window = 2)
 #' kwic(toks, pattern = phrase("war against"), valuetype = "regex", window = 2)
-#' 
+#'
 #' # use index
 #' idx <- index(toks, phrase("secur* against"))
 #' kwic(toks, index = idx, window = 2)
+#' }
 kwic <- function(x, pattern, window = 5,
                  valuetype = c("glob", "regex", "fixed"),
                  separator = " ",
-                 case_insensitive = TRUE, 
-                 index = NULL, 
+                 case_insensitive = TRUE,
+                 index = NULL,
                  ...) {
     UseMethod("kwic")
 }
@@ -57,7 +59,7 @@ kwic.default <- function(x, ...) {
 #' @export
 kwic.character <- function(x, ...) {
     lifecycle::deprecate_stop(
-        when = "3.0", 
+        when = "3.0",
         what = "kwic.character()",
         details = 'Please apply `tokens()` to the character object first.'
     )
@@ -66,7 +68,7 @@ kwic.character <- function(x, ...) {
 #' @export
 kwic.corpus <- function(x, ...) {
     lifecycle::deprecate_stop(
-        when = "3.0", 
+        when = "3.0",
         what = "kwic.corpus()",
         details = 'Please apply `tokens()` to the corpus object first.'
     )
@@ -76,31 +78,31 @@ kwic.corpus <- function(x, ...) {
 kwic.tokens_xptr <- function(x, pattern = NULL, window = 5,
                         valuetype = c("glob", "regex", "fixed"),
                         separator = " ",
-                        case_insensitive = TRUE, 
+                        case_insensitive = TRUE,
                         index = NULL,
                         ...) {
-    
+
     check_dots(..., "kwic")
-    
+
     window <- check_integer(window, 1, 1, 0)
     valuetype <- match.arg(valuetype)
     separator <- check_character(separator)
     case_insensitive <- check_logical(case_insensitive)
-    
+
     if (is.null(pattern) && is.null(index))
         stop("Either pattten or index must be provided\n", call. = FALSE)
     if (!is.null(pattern)) {
-        index <- index(x, pattern = pattern, valuetype = valuetype, 
-                        case_insensitive = case_insensitive)
+        index <- index(x, pattern = pattern, valuetype = valuetype,
+                       case_insensitive = case_insensitive)
     } else if (!is.null(index)) {
         if (!is.index(index))
             stop("Invalid index object\n", call. = FALSE)
     }
-    
+
     n <- ntoken(x)
     index$document <- match(index$docname, docnames(x))
     index <- subset(index, !is.na(index$document))
-    result <- cbind(index, cpp_kwic(x, index$document, index$from, index$to, 
+    result <- cbind(index, cpp_kwic(x, index$document, index$from, index$to,
                                     window, separator, get_threads()))
 
     # reorder columns to match pre-v3 order
@@ -123,7 +125,7 @@ kwic.tokens <- function(x, ...) {
 #' is.kwic(kw)
 #' is.kwic("Not a kwic")
 #' is.kwic(kw[, c("pre", "post")])
-#' 
+#'
 is.kwic <- function(x) {
     inherits(x, "kwic")
 }
@@ -134,7 +136,7 @@ is.kwic <- function(x) {
 #' toks <- tokens(data_corpus_inaugural[1:8])
 #' kw <- kwic(toks, pattern = "secure*", valuetype = "glob", window = 3)
 #' as.data.frame(kw)
-#' 
+#'
 #' @export
 as.data.frame.kwic <- function(x, ...) {
     attr(x, "ntoken") <- NULL
@@ -148,21 +150,21 @@ as.data.frame.kwic <- function(x, ...) {
 #'   `print_kwic_max_nrow` setting of [quanteda_options()]
 #' @importFrom stringi stri_c stri_c_list
 #' @export
-print.kwic <- function(x, max_nrow = quanteda_options("print_kwic_max_nrow"), 
+print.kwic <- function(x, max_nrow = quanteda_options("print_kwic_max_nrow"),
                        show_summary = quanteda_options("print_kwic_summary"), ...) {
 
     max_nrow <- check_integer(max_nrow, min = -1)
     if (max_nrow < 0)
         max_nrow <- nrow(x)
     nrem <- max(0, nrow(x) - max_nrow)
-    
+
     x <- head(x, max_nrow)
     if (show_summary) {
-        cat(msg("Keyword-in-context with %d %s",
-                list(nrow(x) + nrem, c("match", "matches")),
-                list(1, nrow(x) + nrem != 1)), ".", sep = "")
+        cat(msg("Keyword-in-context with %s %s.",
+                nrow(x) + nrem,
+                if (nrow(x) + nrem == 1) "match" else "matches"))
     }
-    
+
     if (nrow(x)) {
         if (all(x$from == x$to)) {
             labels <- stri_c("[", x$docname, ", ", x$from, "]")
@@ -181,15 +183,12 @@ print.kwic <- function(x, max_nrow = quanteda_options("print_kwic_max_nrow"),
         print(result, row.names = FALSE)
 
         if (nrem > 0) {
-            cat("[", sep = "") 
-            if (nrem > 0) {
-                cat(" reached max_nrow ... ", format(nrem, big.mark = ","), " more match", sep = "") 
-                if (nrem > 1) cat("es", sep = "")
-            }
-            cat(" ]\n", sep = "") 
+            cat(msg("[ reached max_nrow ... %s more %s]",
+                    nrem,
+                    if (nrem == 1) "match" else "matches"))
         }
     }
-    cat("\n", sep = "") 
+    cat("\n", sep = "")
 }
 
 #' @method [ kwic
