@@ -3,9 +3,9 @@
 //#include "dev.h"
 using namespace quanteda;
 
-int adjust_window(Text &tokens, int current, int end) {
-    int i = current; 
-    if (end < current) {
+int adjust_window(Text &tokens, int begin, int end) {
+    int i = begin; 
+    if (end < begin) {
         while (i - 1 >= 0 && i - 1 >= end && tokens[i - 1] != 0) i--;
     } else {
         while (i + 1 < (int)tokens.size() && i + 1 < end && tokens[i + 1] != 0) i++;
@@ -13,17 +13,28 @@ int adjust_window(Text &tokens, int current, int end) {
     return(i);
 }
 
+bool is_nested(std::vector<bool> &flags, int begin, int end) {
+    begin = std::max(0, begin);
+    end = std::min(end, (int)flags.size());
+    for (int i = begin; i < end; i++) {
+        if (!flags[i])
+            return(false);
+    }
+    return(true);
+}
+
 Text join_comp(Text tokens, 
                const std::vector<std::size_t> &spans,
                const SetNgrams &set_comps,
                MapNgrams &map_comps,
                IdNgram &id_comp,
+               const bool &keep,
                const std::pair<int, int> &window){
     
     if (tokens.empty()) return {}; // return empty vector for empty text
     
     std::vector< bool > flags_link(tokens.size(), false); // flag tokens to join
-    std::size_t match = 0;
+    std::size_t match = tokens.size();
     
     for (std::size_t span : spans) { // substitution starts from the longest sequences
         if (tokens.size() < span) continue;
@@ -44,7 +55,7 @@ Text join_comp(Text tokens,
     if (match == 0) return tokens; // return original tokens if no match
     
     Text tokens_flat;
-    tokens_flat.reserve(tokens.size());
+    tokens_flat.reserve(match);
     
     Ngram tokens_seq;
     tokens_seq.reserve(tokens.size());
@@ -54,12 +65,14 @@ Text join_comp(Text tokens,
     for (std::size_t i = 0; i < len; i++) {
         //Rcout << "Flag "<< i << ":" << flags_link[i] << "\n";
         if (flags_link[i]) {
-                tokens_seq.push_back(tokens[i]);
+            tokens_seq.push_back(tokens[i]);
         } else {
             if (tokens_seq.empty()) {
                 tokens_flat.push_back(tokens[i]);
             } else {
                 tokens_seq.push_back(tokens[i]);
+                if (keep)
+                    tokens_flat.insert(tokens_flat.end(), tokens_seq.begin(), tokens_seq.end());
                 tokens_flat.push_back(ngram_id(tokens_seq, map_comps, id_comp)); // assign ID to ngram
                 tokens_seq.clear();
             }
@@ -74,28 +87,28 @@ Text match_comp(Text tokens,
                 const SetNgrams &set_comps,
                 MapNgrams &map_comps,
                 IdNgram &id_comp,
+                const bool &keep,
                 const std::pair<int, int> &window){
     
     if (tokens.empty()) return {}; // return empty vector for empty text
     
-    std::vector< std::vector<unsigned int> > tokens_multi(tokens.size()); 
+    std::vector< Text > tokens_multi(tokens.size()); 
     std::vector< bool > flags_match(tokens.size(), false); // flag matched tokens
-    std::vector< bool > flags_link(tokens.size(), false); // flag tokens to join
-    std::size_t match = 0;
-
+    std::size_t match = tokens.size();
+    
     for (std::size_t span : spans) { // substitution starts from the longest sequences
         if (tokens.size() < span) continue;
         for (std::size_t i = 0; i < tokens.size() - (span - 1); i++) {
-            //if (!nested && flags_link[i]) continue; // ignore matched tokens 
             Ngram ngram(tokens.begin() + i, tokens.begin() + i + span);
             auto it = set_comps.find(ngram);
             if (it != set_comps.end()) {
+                if (is_nested(flags_match, i, i + span)) continue; // ignore nested tokens 
                 // Adjust window size to exclude padding
                 int from = adjust_window(tokens, i, i - window.first);
                 int to = adjust_window(tokens, i, i + span + window.second);
                 std::fill(flags_match.begin() + from, flags_match.begin() + to + 1, true); // mark tokens matched
                 Ngram tokens_seq(tokens.begin() + from, tokens.begin() + to + 1); // extract tokens matched
-                tokens_multi[i].push_back(ngram_id(tokens_seq, map_comps, id_comp)); // assign ID to ngram
+                tokens_multi[i + span - 1].push_back(ngram_id(tokens_seq, map_comps, id_comp)); // assign ID to ngram
                 match++;
             }
         }
@@ -103,20 +116,19 @@ Text match_comp(Text tokens,
     
     if (match == 0) return tokens; // return original tokens if no match
     
-    // Add original tokens that did not match
-    for (std::size_t i = 0; i < tokens.size(); i++) {
-        if (!flags_match[i]) {
-            tokens_multi[i].push_back(tokens[i]);
-            match++;
-        }
-    }
-
-    // Flatten the vector of vector
     Text tokens_flat;
     tokens_flat.reserve(match);
-    for (auto &tokens_sub: tokens_multi) {
-        if (!tokens_sub.empty()) {
-            tokens_flat.insert(tokens_flat.end(), tokens_sub.begin(), tokens_sub.begin() + 1);
+    
+    // Flatten the vector of vector
+    for (std::size_t i = 0; i < tokens_multi.size(); i++) {
+        Text tokens_sub = tokens_multi[i];
+        if (!flags_match[i]) {
+            tokens_flat.push_back(tokens[i]);
+        } else {
+            if (keep)
+                tokens_flat.push_back(tokens[i]);
+            if (tokens_sub.size())
+                tokens_flat.insert(tokens_flat.end(), tokens_sub.begin(), tokens_sub.end());
         }
     }
     return tokens_flat;
@@ -129,6 +141,7 @@ Text match_comp(Text tokens,
  * @param compounds_ list of patterns to substitute
  * @param delim_ character to concatenate types
  * @param join join overlapped features if true
+ * @param keep original unigrams if true
  * @param window_left numbers tokens on the left-hand side of pattern
  * @param window_right numbers tokens on the right-hand side of pattern
  * @param bypass_ select documents to modify: TRUE=modify, FALSE=don't modify
@@ -139,6 +152,7 @@ TokensPtr cpp_tokens_compound(TokensPtr xptr,
                               const List &compounds_,
                               const String &delim_,
                               const bool &join,
+                              const bool &keep,
                               int window_left,
                               int window_right,
                               const LogicalVector bypass_,
@@ -164,20 +178,22 @@ TokensPtr cpp_tokens_compound(TokensPtr xptr,
     set_comps.max_load_factor(GLOBAL_PATTERN_MAX_LOAD_FACTOR);
     MapNgrams map_comps; // for ID generation
     map_comps.max_load_factor(GLOBAL_NGRAMS_MAX_LOAD_FACTOR);
-
-    Ngrams comps = Rcpp::as<Ngrams>(compounds_);
-    std::vector<std::size_t> spans(comps.size());
-    for (std::size_t g = 0; g < comps.size(); g++) {
-        Ngram comp = comps[g];
-        // ignore patterns with paddings
-        if (std::find(comp.begin(), comp.end(), 0) == comp.end()) {
-            set_comps.insert(comp);
-            spans[g] = comp.size();
-        }
-    }
-    sort(spans.begin(), spans.end());
-    spans.erase(unique(spans.begin(), spans.end()), spans.end());
-    std::reverse(std::begin(spans), std::end(spans));
+    
+    std::vector<std::size_t> spans = register_ngrams(compounds_, set_comps, true);
+    
+    // Ngrams comps = Rcpp::as<Ngrams>(compounds_);
+    // std::vector<std::size_t> spans(comps.size());
+    // for (std::size_t g = 0; g < comps.size(); g++) {
+    //     Ngram comp = comps[g];
+    //     // ignore patterns with paddings
+    //     if (std::find(comp.begin(), comp.end(), 0) == comp.end()) {
+    //         set_comps.insert(comp);
+    //         spans[g] = comp.size();
+    //     }
+    // }
+    // sort(spans.begin(), spans.end());
+    // spans.erase(unique(spans.begin(), spans.end()), spans.end());
+    // std::reverse(std::begin(spans), std::end(spans));
      
     // dev::Timer timer;
     // dev::start_timer("Token compound", timer);
@@ -190,9 +206,11 @@ TokensPtr cpp_tokens_compound(TokensPtr xptr,
                 if (bypass[h])
                     continue;
                 if (join) {
-                    texts[h] = join_comp(texts[h], spans, set_comps, map_comps, id_comp, window);
+                    texts[h] = join_comp(texts[h], spans, set_comps, map_comps, id_comp, 
+                                         keep, window);
                 } else {
-                    texts[h] = match_comp(texts[h], spans, set_comps, map_comps, id_comp, window);
+                    texts[h] = match_comp(texts[h], spans, set_comps, map_comps, id_comp, 
+                                          keep, window);
                 }
             }    
         });
@@ -202,9 +220,9 @@ TokensPtr cpp_tokens_compound(TokensPtr xptr,
         if (bypass[h])
             continue;
         if (join) {
-            texts[h] = join_comp(texts[h], spans, set_comps, map_comps, id_comp, window);
+            texts[h] = join_comp(texts[h], spans, set_comps, map_comps, id_comp, keep, window);
         } else {
-            texts[h] = match_comp(texts[h], spans, set_comps, map_comps, id_comp, window);
+            texts[h] = match_comp(texts[h], spans, set_comps, map_comps, id_comp, keep, window);
         }
     }
 #endif
