@@ -1,5 +1,3 @@
-context("test corpus_sample")
-
 corp <- corpus(c(one = "Sentence one.  Sentence two.  Third sentence.",
                  two = "First sentence, doc2.  Second sentence, doc2."))
 corp_sent <- corpus_reshape(corp, to = "sentences")
@@ -12,21 +10,14 @@ test_that("test corpus_sample to see if without grouping, documents can be overs
 
 test_that("test corpus_sample to see if with grouping, documents can be oversampled", {
     for (i in 1:10) {
-        corp_samp <- corpus_sample(corp_sent, replace = TRUE, by = "document")
+        corp_samp <- corpus_sample(corp_sent, replace = TRUE, by = docid(corp_sent))
         expect_equal(
-            sum(stringi::stri_detect_regex(docnames(corpus_sample(corp_samp, replace = TRUE, by = "docid_")), "^one")),
+            sum(stringi::stri_detect_regex(docnames(corpus_sample(corp_samp, replace = TRUE, by = docid_)), "^one")),
             3
         )
     }
 })
 
-test_that("corpus with prob does not work with by", {
-    expect_error(
-        corpus_sample(corp_sent, prob = rep(0.2, 5), by = docnames(corp_sent)),
-        "prob not implemented with by"
-    )
-})
-
 test_that("corpus_sample by group works", {
     corp <- corpus(
         paste("Document number", seq_len(10)),
@@ -35,15 +26,15 @@ test_that("corpus_sample by group works", {
                              stringsAsFactors = FALSE)
     )
     expect_equal(
-        docvars(corpus_sample(corp, size = 2, by = "grp"), "grp"),
+        docvars(corpus_sample(corp, size = 2, by = grp), "grp"),
         rep(LETTERS[1:2], each = 2)
     )
     expect_equal(
-        docvars(corpus_sample(corp, size = 25, by = "grp", replace = TRUE), "grp"),
+        docvars(corpus_sample(corp, size = 25, by = grp, replace = TRUE), "grp"),
         rep(LETTERS[1:2], each = 25)
     )
     expect_equal(
-        docvars(corpus_sample(corp, by = "grp"), "grp"),
+        docvars(corpus_sample(corp, by = grp), "grp"),
         rep(LETTERS[1:2], each = 5)
     )
 })
